# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import integer


class AwsLogSource(AWSObject):
    """
    `AwsLogSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-awslogsource.html>`__
    """

    resource_type = "AWS::SecurityLake::AwsLogSource"

    props: PropsDictType = {
        "Accounts": ([str], False),
        "DataLakeArn": (str, True),
        "SourceName": (str, True),
        "SourceVersion": (str, True),
    }


class EncryptionConfiguration(AWSProperty):
    """
    `EncryptionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-encryptionconfiguration.html>`__
    """

    props: PropsDictType = {
        "KmsKeyId": (str, False),
    }


class Expiration(AWSProperty):
    """
    `Expiration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-expiration.html>`__
    """

    props: PropsDictType = {
        "Days": (integer, False),
    }


class Transitions(AWSProperty):
    """
    `Transitions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-transitions.html>`__
    """

    props: PropsDictType = {
        "Days": (integer, False),
        "StorageClass": (str, False),
    }


class LifecycleConfiguration(AWSProperty):
    """
    `LifecycleConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-lifecycleconfiguration.html>`__
    """

    props: PropsDictType = {
        "Expiration": (Expiration, False),
        "Transitions": ([Transitions], False),
    }


class ReplicationConfiguration(AWSProperty):
    """
    `ReplicationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-datalake-replicationconfiguration.html>`__
    """

    props: PropsDictType = {
        "Regions": ([str], False),
        "RoleArn": (str, False),
    }


class DataLake(AWSObject):
    """
    `DataLake <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-datalake.html>`__
    """

    resource_type = "AWS::SecurityLake::DataLake"

    props: PropsDictType = {
        "EncryptionConfiguration": (EncryptionConfiguration, False),
        "LifecycleConfiguration": (LifecycleConfiguration, False),
        "MetaStoreManagerRoleArn": (str, False),
        "ReplicationConfiguration": (ReplicationConfiguration, False),
        "Tags": (Tags, False),
    }


class AwsLogSourceProperty(AWSProperty):
    """
    `AwsLogSourceProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-awslogsource.html>`__
    """

    props: PropsDictType = {
        "SourceName": (str, False),
        "SourceVersion": (str, False),
    }


class CustomLogSource(AWSProperty):
    """
    `CustomLogSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-customlogsource.html>`__
    """

    props: PropsDictType = {
        "SourceName": (str, False),
        "SourceVersion": (str, False),
    }


class Source(AWSProperty):
    """
    `Source <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-source.html>`__
    """

    props: PropsDictType = {
        "AwsLogSource": (AwsLogSourceProperty, False),
        "CustomLogSource": (CustomLogSource, False),
    }


class SubscriberIdentity(AWSProperty):
    """
    `SubscriberIdentity <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscriber-subscriberidentity.html>`__
    """

    props: PropsDictType = {
        "ExternalId": (str, True),
        "Principal": (str, True),
    }


class Subscriber(AWSObject):
    """
    `Subscriber <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscriber.html>`__
    """

    resource_type = "AWS::SecurityLake::Subscriber"

    props: PropsDictType = {
        "AccessTypes": ([str], True),
        "DataLakeArn": (str, True),
        "Sources": ([Source], True),
        "SubscriberDescription": (str, False),
        "SubscriberIdentity": (SubscriberIdentity, True),
        "SubscriberName": (str, True),
        "Tags": (Tags, False),
    }


class HttpsNotificationConfiguration(AWSProperty):
    """
    `HttpsNotificationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscribernotification-httpsnotificationconfiguration.html>`__
    """

    props: PropsDictType = {
        "AuthorizationApiKeyName": (str, False),
        "AuthorizationApiKeyValue": (str, False),
        "Endpoint": (str, True),
        "HttpMethod": (str, False),
        "TargetRoleArn": (str, True),
    }


class NotificationConfiguration(AWSProperty):
    """
    `NotificationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securitylake-subscribernotification-notificationconfiguration.html>`__
    """

    props: PropsDictType = {
        "HttpsNotificationConfiguration": (HttpsNotificationConfiguration, False),
        "SqsNotificationConfiguration": (dict, False),
    }


class SubscriberNotification(AWSObject):
    """
    `SubscriberNotification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securitylake-subscribernotification.html>`__
    """

    resource_type = "AWS::SecurityLake::SubscriberNotification"

    props: PropsDictType = {
        "NotificationConfiguration": (NotificationConfiguration, True),
        "SubscriberArn": (str, True),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean, double, integer


class NoteUpdate(AWSProperty):
    """
    `NoteUpdate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-noteupdate.html>`__
    """

    props: PropsDictType = {
        "Text": (str, True),
        "UpdatedBy": (dict, True),
    }


class RelatedFinding(AWSProperty):
    """
    `RelatedFinding <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-relatedfinding.html>`__
    """

    props: PropsDictType = {
        "Id": (dict, True),
        "ProductArn": (str, True),
    }


class SeverityUpdate(AWSProperty):
    """
    `SeverityUpdate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-severityupdate.html>`__
    """

    props: PropsDictType = {
        "Label": (str, False),
        "Normalized": (integer, False),
        "Product": (double, False),
    }


class WorkflowUpdate(AWSProperty):
    """
    `WorkflowUpdate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-workflowupdate.html>`__
    """

    props: PropsDictType = {
        "Status": (str, True),
    }


class AutomationRulesFindingFieldsUpdate(AWSProperty):
    """
    `AutomationRulesFindingFieldsUpdate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-automationrulesfindingfieldsupdate.html>`__
    """

    props: PropsDictType = {
        "Confidence": (integer, False),
        "Criticality": (integer, False),
        "Note": (NoteUpdate, False),
        "RelatedFindings": ([RelatedFinding], False),
        "Severity": (SeverityUpdate, False),
        "Types": ([str], False),
        "UserDefinedFields": (dict, False),
        "VerificationState": (str, False),
        "Workflow": (WorkflowUpdate, False),
    }


class AutomationRulesAction(AWSProperty):
    """
    `AutomationRulesAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-automationrulesaction.html>`__
    """

    props: PropsDictType = {
        "FindingFieldsUpdate": (AutomationRulesFindingFieldsUpdate, True),
        "Type": (str, True),
    }


class DateRange(AWSProperty):
    """
    `DateRange <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-insight-daterange.html>`__
    """

    props: PropsDictType = {
        "Unit": (str, True),
        "Value": (double, True),
    }


class DateFilter(AWSProperty):
    """
    `DateFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-insight-datefilter.html>`__
    """

    props: PropsDictType = {
        "DateRange": (DateRange, False),
        "End": (str, False),
        "Start": (str, False),
    }


class MapFilter(AWSProperty):
    """
    `MapFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-insight-mapfilter.html>`__
    """

    props: PropsDictType = {
        "Comparison": (str, True),
        "Key": (str, True),
        "Value": (str, True),
    }


class NumberFilter(AWSProperty):
    """
    `NumberFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-insight-numberfilter.html>`__
    """

    props: PropsDictType = {
        "Eq": (double, False),
        "Gte": (double, False),
        "Lte": (double, False),
    }


class StringFilter(AWSProperty):
    """
    `StringFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-insight-stringfilter.html>`__
    """

    props: PropsDictType = {
        "Comparison": (str, True),
        "Value": (str, True),
    }


class AutomationRulesFindingFilters(AWSProperty):
    """
    `AutomationRulesFindingFilters <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-automationrulesfindingfilters.html>`__
    """

    props: PropsDictType = {
        "AwsAccountId": ([StringFilter], False),
        "CompanyName": ([StringFilter], False),
        "ComplianceAssociatedStandardsId": ([StringFilter], False),
        "ComplianceSecurityControlId": ([StringFilter], False),
        "ComplianceStatus": ([StringFilter], False),
        "Confidence": ([NumberFilter], False),
        "CreatedAt": ([DateFilter], False),
        "Criticality": ([NumberFilter], False),
        "Description": ([StringFilter], False),
        "FirstObservedAt": ([DateFilter], False),
        "GeneratorId": ([StringFilter], False),
        "Id": ([StringFilter], False),
        "LastObservedAt": ([DateFilter], False),
        "NoteText": ([StringFilter], False),
        "NoteUpdatedAt": ([DateFilter], False),
        "NoteUpdatedBy": ([StringFilter], False),
        "ProductArn": ([StringFilter], False),
        "ProductName": ([StringFilter], False),
        "RecordState": ([StringFilter], False),
        "RelatedFindingsId": ([StringFilter], False),
        "RelatedFindingsProductArn": ([StringFilter], False),
        "ResourceDetailsOther": ([MapFilter], False),
        "ResourceId": ([StringFilter], False),
        "ResourcePartition": ([StringFilter], False),
        "ResourceRegion": ([StringFilter], False),
        "ResourceTags": ([MapFilter], False),
        "ResourceType": ([StringFilter], False),
        "SeverityLabel": ([StringFilter], False),
        "SourceUrl": ([StringFilter], False),
        "Title": ([StringFilter], False),
        "Type": ([StringFilter], False),
        "UpdatedAt": ([DateFilter], False),
        "UserDefinedFields": ([MapFilter], False),
        "VerificationState": ([StringFilter], False),
        "WorkflowStatus": ([StringFilter], False),
    }


class AutomationRule(AWSObject):
    """
    `AutomationRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-automationrule.html>`__
    """

    resource_type = "AWS::SecurityHub::AutomationRule"

    props: PropsDictType = {
        "Actions": ([AutomationRulesAction], True),
        "Criteria": (AutomationRulesFindingFilters, True),
        "Description": (str, True),
        "IsTerminal": (boolean, False),
        "RuleName": (str, True),
        "RuleOrder": (integer, True),
        "RuleStatus": (str, False),
        "Tags": (dict, False),
    }


class ParameterValue(AWSProperty):
    """
    `ParameterValue <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-securitycontrol-parametervalue.html>`__
    """

    props: PropsDictType = {
        "Boolean": (boolean, False),
        "Double": (double, False),
        "Enum": (str, False),
        "EnumList": ([str], False),
        "Integer": (integer, False),
        "IntegerList": ([integer], False),
        "String": (str, False),
        "StringList": ([str], False),
    }


class ParameterConfiguration(AWSProperty):
    """
    `ParameterConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-securitycontrol-parameterconfiguration.html>`__
    """

    props: PropsDictType = {
        "Value": (ParameterValue, False),
        "ValueType": (str, True),
    }


class SecurityControlCustomParameter(AWSProperty):
    """
    `SecurityControlCustomParameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-configurationpolicy-securitycontrolcustomparameter.html>`__
    """

    props: PropsDictType = {
        "Parameters": (dict, False),
        "SecurityControlId": (str, False),
    }


class SecurityControlsConfiguration(AWSProperty):
    """
    `SecurityControlsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-configurationpolicy-securitycontrolsconfiguration.html>`__
    """

    props: PropsDictType = {
        "DisabledSecurityControlIdentifiers": ([str], False),
        "EnabledSecurityControlIdentifiers": ([str], False),
        "SecurityControlCustomParameters": ([SecurityControlCustomParameter], False),
    }


class SecurityHubPolicy(AWSProperty):
    """
    `SecurityHubPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-configurationpolicy-securityhubpolicy.html>`__
    """

    props: PropsDictType = {
        "EnabledStandardIdentifiers": ([str], False),
        "SecurityControlsConfiguration": (SecurityControlsConfiguration, False),
        "ServiceEnabled": (boolean, False),
    }


class Policy(AWSProperty):
    """
    `Policy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-configurationpolicy-policy.html>`__
    """

    props: PropsDictType = {
        "SecurityHub": (SecurityHubPolicy, False),
    }


class ConfigurationPolicy(AWSObject):
    """
    `ConfigurationPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-configurationpolicy.html>`__
    """

    resource_type = "AWS::SecurityHub::ConfigurationPolicy"

    props: PropsDictType = {
        "ConfigurationPolicy": (Policy, True),
        "Description": (str, False),
        "Name": (str, True),
        "Tags": (dict, False),
    }


class DelegatedAdmin(AWSObject):
    """
    `DelegatedAdmin <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-delegatedadmin.html>`__
    """

    resource_type = "AWS::SecurityHub::DelegatedAdmin"

    props: PropsDictType = {
        "AdminAccountId": (str, True),
    }


class FindingAggregator(AWSObject):
    """
    `FindingAggregator <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-findingaggregator.html>`__
    """

    resource_type = "AWS::SecurityHub::FindingAggregator"

    props: PropsDictType = {
        "RegionLinkingMode": (str, True),
        "Regions": ([str], False),
    }


class Hub(AWSObject):
    """
    `Hub <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-hub.html>`__
    """

    resource_type = "AWS::SecurityHub::Hub"

    props: PropsDictType = {
        "AutoEnableControls": (boolean, False),
        "ControlFindingGenerator": (str, False),
        "EnableDefaultStandards": (boolean, False),
        "Tags": (dict, False),
    }


class BooleanFilter(AWSProperty):
    """
    `BooleanFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-insight-booleanfilter.html>`__
    """

    props: PropsDictType = {
        "Value": (boolean, True),
    }


class IpFilter(AWSProperty):
    """
    `IpFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-insight-ipfilter.html>`__
    """

    props: PropsDictType = {
        "Cidr": (str, True),
    }


class AwsSecurityFindingFilters(AWSProperty):
    """
    `AwsSecurityFindingFilters <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-insight-awssecurityfindingfilters.html>`__
    """

    props: PropsDictType = {
        "AwsAccountId": ([StringFilter], False),
        "AwsAccountName": ([StringFilter], False),
        "CompanyName": ([StringFilter], False),
        "ComplianceAssociatedStandardsId": ([StringFilter], False),
        "ComplianceSecurityControlId": ([StringFilter], False),
        "ComplianceSecurityControlParametersName": ([StringFilter], False),
        "ComplianceSecurityControlParametersValue": ([StringFilter], False),
        "ComplianceStatus": ([StringFilter], False),
        "Confidence": ([NumberFilter], False),
        "CreatedAt": ([DateFilter], False),
        "Criticality": ([NumberFilter], False),
        "Description": ([StringFilter], False),
        "FindingProviderFieldsConfidence": ([NumberFilter], False),
        "FindingProviderFieldsCriticality": ([NumberFilter], False),
        "FindingProviderFieldsRelatedFindingsId": ([StringFilter], False),
        "FindingProviderFieldsRelatedFindingsProductArn": ([StringFilter], False),
        "FindingProviderFieldsSeverityLabel": ([StringFilter], False),
        "FindingProviderFieldsSeverityOriginal": ([StringFilter], False),
        "FindingProviderFieldsTypes": ([StringFilter], False),
        "FirstObservedAt": ([DateFilter], False),
        "GeneratorId": ([StringFilter], False),
        "Id": ([StringFilter], False),
        "LastObservedAt": ([DateFilter], False),
        "MalwareName": ([StringFilter], False),
        "MalwarePath": ([StringFilter], False),
        "MalwareState": ([StringFilter], False),
        "MalwareType": ([StringFilter], False),
        "NetworkDestinationDomain": ([StringFilter], False),
        "NetworkDestinationIpV4": ([IpFilter], False),
        "NetworkDestinationIpV6": ([IpFilter], False),
        "NetworkDestinationPort": ([NumberFilter], False),
        "NetworkDirection": ([StringFilter], False),
        "NetworkProtocol": ([StringFilter], False),
        "NetworkSourceDomain": ([StringFilter], False),
        "NetworkSourceIpV4": ([IpFilter], False),
        "NetworkSourceIpV6": ([IpFilter], False),
        "NetworkSourceMac": ([StringFilter], False),
        "NetworkSourcePort": ([NumberFilter], False),
        "NoteText": ([StringFilter], False),
        "NoteUpdatedAt": ([DateFilter], False),
        "NoteUpdatedBy": ([StringFilter], False),
        "ProcessLaunchedAt": ([DateFilter], False),
        "ProcessName": ([StringFilter], False),
        "ProcessParentPid": ([NumberFilter], False),
        "ProcessPath": ([StringFilter], False),
        "ProcessPid": ([NumberFilter], False),
        "ProcessTerminatedAt": ([DateFilter], False),
        "ProductArn": ([StringFilter], False),
        "ProductFields": ([MapFilter], False),
        "ProductName": ([StringFilter], False),
        "RecommendationText": ([StringFilter], False),
        "RecordState": ([StringFilter], False),
        "Region": ([StringFilter], False),
        "RelatedFindingsId": ([StringFilter], False),
        "RelatedFindingsProductArn": ([StringFilter], False),
        "ResourceApplicationArn": ([StringFilter], False),
        "ResourceApplicationName": ([StringFilter], False),
        "ResourceAwsEc2InstanceIamInstanceProfileArn": ([StringFilter], False),
        "ResourceAwsEc2InstanceImageId": ([StringFilter], False),
        "ResourceAwsEc2InstanceIpV4Addresses": ([IpFilter], False),
        "ResourceAwsEc2InstanceIpV6Addresses": ([IpFilter], False),
        "ResourceAwsEc2InstanceKeyName": ([StringFilter], False),
        "ResourceAwsEc2InstanceLaunchedAt": ([DateFilter], False),
        "ResourceAwsEc2InstanceSubnetId": ([StringFilter], False),
        "ResourceAwsEc2InstanceType": ([StringFilter], False),
        "ResourceAwsEc2InstanceVpcId": ([StringFilter], False),
        "ResourceAwsIamAccessKeyCreatedAt": ([DateFilter], False),
        "ResourceAwsIamAccessKeyPrincipalName": ([StringFilter], False),
        "ResourceAwsIamAccessKeyStatus": ([StringFilter], False),
        "ResourceAwsIamUserUserName": ([StringFilter], False),
        "ResourceAwsS3BucketOwnerId": ([StringFilter], False),
        "ResourceAwsS3BucketOwnerName": ([StringFilter], False),
        "ResourceContainerImageId": ([StringFilter], False),
        "ResourceContainerImageName": ([StringFilter], False),
        "ResourceContainerLaunchedAt": ([DateFilter], False),
        "ResourceContainerName": ([StringFilter], False),
        "ResourceDetailsOther": ([MapFilter], False),
        "ResourceId": ([StringFilter], False),
        "ResourcePartition": ([StringFilter], False),
        "ResourceRegion": ([StringFilter], False),
        "ResourceTags": ([MapFilter], False),
        "ResourceType": ([StringFilter], False),
        "Sample": ([BooleanFilter], False),
        "SeverityLabel": ([StringFilter], False),
        "SourceUrl": ([StringFilter], False),
        "ThreatIntelIndicatorCategory": ([StringFilter], False),
        "ThreatIntelIndicatorLastObservedAt": ([DateFilter], False),
        "ThreatIntelIndicatorSource": ([StringFilter], False),
        "ThreatIntelIndicatorSourceUrl": ([StringFilter], False),
        "ThreatIntelIndicatorType": ([StringFilter], False),
        "ThreatIntelIndicatorValue": ([StringFilter], False),
        "Title": ([StringFilter], False),
        "Type": ([StringFilter], False),
        "UpdatedAt": ([DateFilter], False),
        "UserDefinedFields": ([MapFilter], False),
        "VerificationState": ([StringFilter], False),
        "VulnerabilitiesExploitAvailable": ([StringFilter], False),
        "VulnerabilitiesFixAvailable": ([StringFilter], False),
        "WorkflowState": ([StringFilter], False),
        "WorkflowStatus": ([StringFilter], False),
    }


class Insight(AWSObject):
    """
    `Insight <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-insight.html>`__
    """

    resource_type = "AWS::SecurityHub::Insight"

    props: PropsDictType = {
        "Filters": (AwsSecurityFindingFilters, True),
        "GroupByAttribute": (str, True),
        "Name": (str, True),
    }


class OrganizationConfiguration(AWSObject):
    """
    `OrganizationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-organizationconfiguration.html>`__
    """

    resource_type = "AWS::SecurityHub::OrganizationConfiguration"

    props: PropsDictType = {
        "AutoEnable": (boolean, True),
        "AutoEnableStandards": (str, False),
        "ConfigurationType": (str, False),
    }


class PolicyAssociation(AWSObject):
    """
    `PolicyAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-policyassociation.html>`__
    """

    resource_type = "AWS::SecurityHub::PolicyAssociation"

    props: PropsDictType = {
        "ConfigurationPolicyId": (str, True),
        "TargetId": (str, True),
        "TargetType": (str, True),
    }


class ProductSubscription(AWSObject):
    """
    `ProductSubscription <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-productsubscription.html>`__
    """

    resource_type = "AWS::SecurityHub::ProductSubscription"

    props: PropsDictType = {
        "ProductArn": (str, True),
    }


class SecurityControl(AWSObject):
    """
    `SecurityControl <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-securitycontrol.html>`__
    """

    resource_type = "AWS::SecurityHub::SecurityControl"

    props: PropsDictType = {
        "LastUpdateReason": (str, False),
        "Parameters": (dict, True),
        "SecurityControlArn": (str, False),
        "SecurityControlId": (str, False),
    }


class StandardsControl(AWSProperty):
    """
    `StandardsControl <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-standard-standardscontrol.html>`__
    """

    props: PropsDictType = {
        "Reason": (str, False),
        "StandardsControlArn": (str, True),
    }


class Standard(AWSObject):
    """
    `Standard <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-standard.html>`__
    """

    resource_type = "AWS::SecurityHub::Standard"

    props: PropsDictType = {
        "DisabledStandardsControls": ([StandardsControl], False),
        "StandardsArn": (str, True),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, double, integer


class Channel(AWSObject):
    """
    `Channel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-channel.html>`__
    """

    resource_type = "AWS::IVS::Channel"

    props: PropsDictType = {
        "Authorized": (boolean, False),
        "InsecureIngest": (boolean, False),
        "LatencyMode": (str, False),
        "Name": (str, False),
        "Preset": (str, False),
        "RecordingConfigurationArn": (str, False),
        "Tags": (Tags, False),
        "Type": (str, False),
    }


class Video(AWSProperty):
    """
    `Video <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-encoderconfiguration-video.html>`__
    """

    props: PropsDictType = {
        "Bitrate": (integer, False),
        "Framerate": (double, False),
        "Height": (integer, False),
        "Width": (integer, False),
    }


class EncoderConfiguration(AWSObject):
    """
    `EncoderConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-encoderconfiguration.html>`__
    """

    resource_type = "AWS::IVS::EncoderConfiguration"

    props: PropsDictType = {
        "Name": (str, False),
        "Tags": (Tags, False),
        "Video": (Video, False),
    }


class PlaybackKeyPair(AWSObject):
    """
    `PlaybackKeyPair <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-playbackkeypair.html>`__
    """

    resource_type = "AWS::IVS::PlaybackKeyPair"

    props: PropsDictType = {
        "Name": (str, False),
        "PublicKeyMaterial": (str, False),
        "Tags": (Tags, False),
    }


class PlaybackRestrictionPolicy(AWSObject):
    """
    `PlaybackRestrictionPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-playbackrestrictionpolicy.html>`__
    """

    resource_type = "AWS::IVS::PlaybackRestrictionPolicy"

    props: PropsDictType = {
        "AllowedCountries": ([str], True),
        "AllowedOrigins": ([str], True),
        "EnableStrictOriginEnforcement": (boolean, False),
        "Name": (str, False),
        "Tags": (Tags, False),
    }


class PublicKey(AWSObject):
    """
    `PublicKey <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-publickey.html>`__
    """

    resource_type = "AWS::IVS::PublicKey"

    props: PropsDictType = {
        "Name": (str, False),
        "PublicKeyMaterial": (str, False),
        "Tags": (Tags, False),
    }


class S3DestinationConfiguration(AWSProperty):
    """
    `S3DestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-s3destinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, True),
    }


class DestinationConfiguration(AWSProperty):
    """
    `DestinationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-destinationconfiguration.html>`__
    """

    props: PropsDictType = {
        "S3": (S3DestinationConfiguration, False),
    }


class RenditionConfiguration(AWSProperty):
    """
    `RenditionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-renditionconfiguration.html>`__
    """

    props: PropsDictType = {
        "RenditionSelection": (str, False),
        "Renditions": ([str], False),
    }


class ThumbnailConfiguration(AWSProperty):
    """
    `ThumbnailConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-thumbnailconfiguration.html>`__
    """

    props: PropsDictType = {
        "RecordingMode": (str, False),
        "Resolution": (str, False),
        "Storage": ([str], False),
        "TargetIntervalSeconds": (integer, False),
    }


class RecordingConfiguration(AWSObject):
    """
    `RecordingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-recordingconfiguration.html>`__
    """

    resource_type = "AWS::IVS::RecordingConfiguration"

    props: PropsDictType = {
        "DestinationConfiguration": (DestinationConfiguration, True),
        "Name": (str, False),
        "RecordingReconnectWindowSeconds": (integer, False),
        "RenditionConfiguration": (RenditionConfiguration, False),
        "Tags": (Tags, False),
        "ThumbnailConfiguration": (ThumbnailConfiguration, False),
    }


class AutoParticipantRecordingConfiguration(AWSProperty):
    """
    `AutoParticipantRecordingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-stage-autoparticipantrecordingconfiguration.html>`__
    """

    props: PropsDictType = {
        "MediaTypes": ([str], False),
        "StorageConfigurationArn": (str, True),
    }


class Stage(AWSObject):
    """
    `Stage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-stage.html>`__
    """

    resource_type = "AWS::IVS::Stage"

    props: PropsDictType = {
        "AutoParticipantRecordingConfiguration": (
            AutoParticipantRecordingConfiguration,
            False,
        ),
        "Name": (str, False),
        "Tags": (Tags, False),
    }


class S3StorageConfiguration(AWSProperty):
    """
    `S3StorageConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-storageconfiguration-s3storageconfiguration.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, True),
    }


class StorageConfiguration(AWSObject):
    """
    `StorageConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-storageconfiguration.html>`__
    """

    resource_type = "AWS::IVS::StorageConfiguration"

    props: PropsDictType = {
        "Name": (str, False),
        "S3": (S3StorageConfiguration, True),
        "Tags": (Tags, False),
    }


class StreamKey(AWSObject):
    """
    `StreamKey <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ivs-streamkey.html>`__
    """

    resource_type = "AWS::IVS::StreamKey"

    props: PropsDictType = {
        "ChannelArn": (str, True),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import double, integer


class Farm(AWSObject):
    """
    `Farm <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-deadline-farm.html>`__
    """

    resource_type = "AWS::Deadline::Farm"

    props: PropsDictType = {
        "Description": (str, False),
        "DisplayName": (str, True),
        "KmsKeyArn": (str, False),
        "Tags": (Tags, False),
    }


class AcceleratorCountRange(AWSProperty):
    """
    `AcceleratorCountRange <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-acceleratorcountrange.html>`__
    """

    props: PropsDictType = {
        "Max": (integer, False),
        "Min": (integer, True),
    }


class AcceleratorTotalMemoryMiBRange(AWSProperty):
    """
    `AcceleratorTotalMemoryMiBRange <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-acceleratortotalmemorymibrange.html>`__
    """

    props: PropsDictType = {
        "Max": (integer, False),
        "Min": (integer, True),
    }


class FleetAmountCapability(AWSProperty):
    """
    `FleetAmountCapability <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-fleetamountcapability.html>`__
    """

    props: PropsDictType = {
        "Max": (double, False),
        "Min": (double, True),
        "Name": (str, True),
    }


class FleetAttributeCapability(AWSProperty):
    """
    `FleetAttributeCapability <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-fleetattributecapability.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
        "Values": ([str], True),
    }


class MemoryMiBRange(AWSProperty):
    """
    `MemoryMiBRange <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-memorymibrange.html>`__
    """

    props: PropsDictType = {
        "Max": (integer, False),
        "Min": (integer, True),
    }


class VCpuCountRange(AWSProperty):
    """
    `VCpuCountRange <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-vcpucountrange.html>`__
    """

    props: PropsDictType = {
        "Max": (integer, False),
        "Min": (integer, True),
    }


class CustomerManagedWorkerCapabilities(AWSProperty):
    """
    `CustomerManagedWorkerCapabilities <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-customermanagedworkercapabilities.html>`__
    """

    props: PropsDictType = {
        "AcceleratorCount": (AcceleratorCountRange, False),
        "AcceleratorTotalMemoryMiB": (AcceleratorTotalMemoryMiBRange, False),
        "AcceleratorTypes": ([str], False),
        "CpuArchitectureType": (str, True),
        "CustomAmounts": ([FleetAmountCapability], False),
        "CustomAttributes": ([FleetAttributeCapability], False),
        "MemoryMiB": (MemoryMiBRange, True),
        "OsFamily": (str, True),
        "VCpuCount": (VCpuCountRange, True),
    }


class CustomerManagedFleetConfiguration(AWSProperty):
    """
    `CustomerManagedFleetConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-customermanagedfleetconfiguration.html>`__
    """

    props: PropsDictType = {
        "Mode": (str, True),
        "StorageProfileId": (str, False),
        "WorkerCapabilities": (CustomerManagedWorkerCapabilities, True),
    }


class Ec2EbsVolume(AWSProperty):
    """
    `Ec2EbsVolume <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-ec2ebsvolume.html>`__
    """

    props: PropsDictType = {
        "Iops": (integer, False),
        "SizeGiB": (integer, False),
        "ThroughputMiB": (integer, False),
    }


class ServiceManagedEc2InstanceCapabilities(AWSProperty):
    """
    `ServiceManagedEc2InstanceCapabilities <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-servicemanagedec2instancecapabilities.html>`__
    """

    props: PropsDictType = {
        "AllowedInstanceTypes": ([str], False),
        "CpuArchitectureType": (str, True),
        "CustomAmounts": ([FleetAmountCapability], False),
        "CustomAttributes": ([FleetAttributeCapability], False),
        "ExcludedInstanceTypes": ([str], False),
        "MemoryMiB": (MemoryMiBRange, True),
        "OsFamily": (str, True),
        "RootEbsVolume": (Ec2EbsVolume, False),
        "VCpuCount": (VCpuCountRange, True),
    }


class ServiceManagedEc2InstanceMarketOptions(AWSProperty):
    """
    `ServiceManagedEc2InstanceMarketOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-servicemanagedec2instancemarketoptions.html>`__
    """

    props: PropsDictType = {
        "Type": (str, True),
    }


class ServiceManagedEc2FleetConfiguration(AWSProperty):
    """
    `ServiceManagedEc2FleetConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-servicemanagedec2fleetconfiguration.html>`__
    """

    props: PropsDictType = {
        "InstanceCapabilities": (ServiceManagedEc2InstanceCapabilities, True),
        "InstanceMarketOptions": (ServiceManagedEc2InstanceMarketOptions, True),
    }


class FleetConfiguration(AWSProperty):
    """
    `FleetConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-fleetconfiguration.html>`__
    """

    props: PropsDictType = {
        "CustomerManaged": (CustomerManagedFleetConfiguration, False),
        "ServiceManagedEc2": (ServiceManagedEc2FleetConfiguration, False),
    }


class Fleet(AWSObject):
    """
    `Fleet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-deadline-fleet.html>`__
    """

    resource_type = "AWS::Deadline::Fleet"

    props: PropsDictType = {
        "Configuration": (FleetConfiguration, True),
        "Description": (str, False),
        "DisplayName": (str, True),
        "FarmId": (str, True),
        "MaxWorkerCount": (integer, True),
        "MinWorkerCount": (integer, False),
        "RoleArn": (str, True),
        "Tags": (Tags, False),
    }


class LicenseEndpoint(AWSObject):
    """
    `LicenseEndpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-deadline-licenseendpoint.html>`__
    """

    resource_type = "AWS::Deadline::LicenseEndpoint"

    props: PropsDictType = {
        "SecurityGroupIds": ([str], True),
        "SubnetIds": ([str], True),
        "Tags": (Tags, False),
        "VpcId": (str, True),
    }


class MeteredProduct(AWSObject):
    """
    `MeteredProduct <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-deadline-meteredproduct.html>`__
    """

    resource_type = "AWS::Deadline::MeteredProduct"

    props: PropsDictType = {
        "LicenseEndpointId": (str, False),
        "ProductId": (str, False),
    }


class Monitor(AWSObject):
    """
    `Monitor <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-deadline-monitor.html>`__
    """

    resource_type = "AWS::Deadline::Monitor"

    props: PropsDictType = {
        "DisplayName": (str, True),
        "IdentityCenterInstanceArn": (str, True),
        "RoleArn": (str, True),
        "Subdomain": (str, True),
    }


class JobAttachmentSettings(AWSProperty):
    """
    `JobAttachmentSettings <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-queue-jobattachmentsettings.html>`__
    """

    props: PropsDictType = {
        "RootPrefix": (str, True),
        "S3BucketName": (str, True),
    }


class PosixUser(AWSProperty):
    """
    `PosixUser <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-queue-posixuser.html>`__
    """

    props: PropsDictType = {
        "Group": (str, True),
        "User": (str, True),
    }


class WindowsUser(AWSProperty):
    """
    `WindowsUser <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-queue-windowsuser.html>`__
    """

    props: PropsDictType = {
        "PasswordArn": (str, True),
        "User": (str, True),
    }


class JobRunAsUser(AWSProperty):
    """
    `JobRunAsUser <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-queue-jobrunasuser.html>`__
    """

    props: PropsDictType = {
        "Posix": (PosixUser, False),
        "RunAs": (str, True),
        "Windows": (WindowsUser, False),
    }


class Queue(AWSObject):
    """
    `Queue <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-deadline-queue.html>`__
    """

    resource_type = "AWS::Deadline::Queue"

    props: PropsDictType = {
        "AllowedStorageProfileIds": ([str], False),
        "DefaultBudgetAction": (str, False),
        "Description": (str, False),
        "DisplayName": (str, True),
        "FarmId": (str, True),
        "JobAttachmentSettings": (JobAttachmentSettings, False),
        "JobRunAsUser": (JobRunAsUser, False),
        "RequiredFileSystemLocationNames": ([str], False),
        "RoleArn": (str, False),
        "Tags": (Tags, False),
    }


class QueueEnvironment(AWSObject):
    """
    `QueueEnvironment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-deadline-queueenvironment.html>`__
    """

    resource_type = "AWS::Deadline::QueueEnvironment"

    props: PropsDictType = {
        "FarmId": (str, True),
        "Priority": (integer, True),
        "QueueId": (str, True),
        "Template": (str, True),
        "TemplateType": (str, True),
    }


class QueueFleetAssociation(AWSObject):
    """
    `QueueFleetAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-deadline-queuefleetassociation.html>`__
    """

    resource_type = "AWS::Deadline::QueueFleetAssociation"

    props: PropsDictType = {
        "FarmId": (str, True),
        "FleetId": (str, True),
        "QueueId": (str, True),
    }


class FileSystemLocation(AWSProperty):
    """
    `FileSystemLocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-storageprofile-filesystemlocation.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
        "Path": (str, True),
        "Type": (str, True),
    }


class StorageProfile(AWSObject):
    """
    `StorageProfile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-deadline-storageprofile.html>`__
    """

    resource_type = "AWS::Deadline::StorageProfile"

    props: PropsDictType = {
        "DisplayName": (str, True),
        "FarmId": (str, True),
        "FileSystemLocations": ([FileSystemLocation], False),
        "OsFamily": (str, True),
    }


class FleetCapabilities(AWSProperty):
    """
    `FleetCapabilities <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-deadline-fleet-fleetcapabilities.html>`__
    """

    props: PropsDictType = {
        "Amounts": ([FleetAmountCapability], False),
        "Attributes": ([FleetAttributeCapability], False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean


class Alias(AWSObject):
    """
    `Alias <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-paymentcryptography-alias.html>`__
    """

    resource_type = "AWS::PaymentCryptography::Alias"

    props: PropsDictType = {
        "AliasName": (str, True),
        "KeyArn": (str, False),
    }


class KeyModesOfUse(AWSProperty):
    """
    `KeyModesOfUse <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-paymentcryptography-key-keymodesofuse.html>`__
    """

    props: PropsDictType = {
        "Decrypt": (boolean, False),
        "DeriveKey": (boolean, False),
        "Encrypt": (boolean, False),
        "Generate": (boolean, False),
        "NoRestrictions": (boolean, False),
        "Sign": (boolean, False),
        "Unwrap": (boolean, False),
        "Verify": (boolean, False),
        "Wrap": (boolean, False),
    }


class KeyAttributes(AWSProperty):
    """
    `KeyAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-paymentcryptography-key-keyattributes.html>`__
    """

    props: PropsDictType = {
        "KeyAlgorithm": (str, True),
        "KeyClass": (str, True),
        "KeyModesOfUse": (KeyModesOfUse, True),
        "KeyUsage": (str, True),
    }


class Key(AWSObject):
    """
    `Key <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-paymentcryptography-key.html>`__
    """

    resource_type = "AWS::PaymentCryptography::Key"

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "Exportable": (boolean, True),
        "KeyAttributes": (KeyAttributes, True),
        "KeyCheckValueAlgorithm": (str, False),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean, double


class DataSet(AWSProperty):
    """
    `DataSet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-dataset.html>`__
    """

    props: PropsDictType = {
        "Ccsid": (str, True),
        "Format": (str, True),
        "Length": (double, True),
        "Name": (str, True),
        "Type": (str, True),
    }


class SourceDatabaseMetadata(AWSProperty):
    """
    `SourceDatabaseMetadata <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-sourcedatabasemetadata.html>`__
    """

    props: PropsDictType = {
        "CaptureTool": (str, True),
        "Type": (str, True),
    }


class TargetDatabaseMetadata(AWSProperty):
    """
    `TargetDatabaseMetadata <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-targetdatabasemetadata.html>`__
    """

    props: PropsDictType = {
        "CaptureTool": (str, True),
        "Type": (str, True),
    }


class DatabaseCDC(AWSProperty):
    """
    `DatabaseCDC <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-databasecdc.html>`__
    """

    props: PropsDictType = {
        "SourceMetadata": (SourceDatabaseMetadata, True),
        "TargetMetadata": (TargetDatabaseMetadata, True),
    }


class FileMetadata(AWSProperty):
    """
    `FileMetadata <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-filemetadata.html>`__
    """

    props: PropsDictType = {
        "DataSets": ([DataSet], False),
        "DatabaseCDC": (DatabaseCDC, False),
    }


class InputFile(AWSProperty):
    """
    `InputFile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-inputfile.html>`__
    """

    props: PropsDictType = {
        "FileMetadata": (FileMetadata, True),
        "SourceLocation": (str, True),
        "TargetLocation": (str, True),
    }


class Input(AWSProperty):
    """
    `Input <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-input.html>`__
    """

    props: PropsDictType = {
        "File": (InputFile, True),
    }


class OutputFile(AWSProperty):
    """
    `OutputFile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-outputfile.html>`__
    """

    props: PropsDictType = {
        "FileLocation": (str, False),
    }


class Output(AWSProperty):
    """
    `Output <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-output.html>`__
    """

    props: PropsDictType = {
        "File": (OutputFile, True),
    }


class CompareAction(AWSProperty):
    """
    `CompareAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-compareaction.html>`__
    """

    props: PropsDictType = {
        "Input": (Input, True),
        "Output": (Output, False),
    }


class MainframeActionProperties(AWSProperty):
    """
    `MainframeActionProperties <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-mainframeactionproperties.html>`__
    """

    props: PropsDictType = {
        "DmsTaskArn": (str, False),
    }


class Batch(AWSProperty):
    """
    `Batch <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-batch.html>`__
    """

    props: PropsDictType = {
        "BatchJobName": (str, True),
        "BatchJobParameters": (dict, False),
        "ExportDataSetNames": ([str], False),
    }


class Script(AWSProperty):
    """
    `Script <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-script.html>`__
    """

    props: PropsDictType = {
        "ScriptLocation": (str, True),
        "Type": (str, True),
    }


class TN3270(AWSProperty):
    """
    `TN3270 <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-tn3270.html>`__
    """

    props: PropsDictType = {
        "ExportDataSetNames": ([str], False),
        "Script": (Script, True),
    }


class MainframeActionType(AWSProperty):
    """
    `MainframeActionType <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-mainframeactiontype.html>`__
    """

    props: PropsDictType = {
        "Batch": (Batch, False),
        "Tn3270": (TN3270, False),
    }


class MainframeAction(AWSProperty):
    """
    `MainframeAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-mainframeaction.html>`__
    """

    props: PropsDictType = {
        "ActionType": (MainframeActionType, True),
        "Properties": (MainframeActionProperties, False),
        "Resource": (str, True),
    }


class CloudFormationAction(AWSProperty):
    """
    `CloudFormationAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-cloudformationaction.html>`__
    """

    props: PropsDictType = {
        "ActionType": (str, False),
        "Resource": (str, True),
    }


class M2ManagedActionProperties(AWSProperty):
    """
    `M2ManagedActionProperties <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-m2managedactionproperties.html>`__
    """

    props: PropsDictType = {
        "ForceStop": (boolean, False),
        "ImportDataSetLocation": (str, False),
    }


class M2ManagedApplicationAction(AWSProperty):
    """
    `M2ManagedApplicationAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-m2managedapplicationaction.html>`__
    """

    props: PropsDictType = {
        "ActionType": (str, True),
        "Properties": (M2ManagedActionProperties, False),
        "Resource": (str, True),
    }


class M2NonManagedApplicationAction(AWSProperty):
    """
    `M2NonManagedApplicationAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-m2nonmanagedapplicationaction.html>`__
    """

    props: PropsDictType = {
        "ActionType": (str, True),
        "Resource": (str, True),
    }


class ResourceAction(AWSProperty):
    """
    `ResourceAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-resourceaction.html>`__
    """

    props: PropsDictType = {
        "CloudFormationAction": (CloudFormationAction, False),
        "M2ManagedApplicationAction": (M2ManagedApplicationAction, False),
        "M2NonManagedApplicationAction": (M2NonManagedApplicationAction, False),
    }


class StepAction(AWSProperty):
    """
    `StepAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-stepaction.html>`__
    """

    props: PropsDictType = {
        "CompareAction": (CompareAction, False),
        "MainframeAction": (MainframeAction, False),
        "ResourceAction": (ResourceAction, False),
    }


class Step(AWSProperty):
    """
    `Step <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-step.html>`__
    """

    props: PropsDictType = {
        "Action": (StepAction, True),
        "Description": (str, False),
        "Name": (str, True),
    }


class TestCase(AWSObject):
    """
    `TestCase <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apptest-testcase.html>`__
    """

    resource_type = "AWS::AppTest::TestCase"

    props: PropsDictType = {
        "Description": (str, False),
        "Name": (str, True),
        "Steps": ([Step], True),
        "Tags": (dict, False),
    }


class TestCaseLatestVersion(AWSProperty):
    """
    `TestCaseLatestVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apptest-testcase-testcaselatestversion.html>`__
    """

    props: PropsDictType = {
        "Status": (str, True),
        "Version": (double, True),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, double, integer


class CalendarInterval(AWSProperty):
    """
    `CalendarInterval <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-calendarinterval.html>`__
    """

    props: PropsDictType = {
        "Duration": (integer, True),
        "DurationUnit": (str, True),
        "StartTime": (integer, True),
    }


class RollingInterval(AWSProperty):
    """
    `RollingInterval <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-rollinginterval.html>`__
    """

    props: PropsDictType = {
        "Duration": (integer, True),
        "DurationUnit": (str, True),
    }


class Interval(AWSProperty):
    """
    `Interval <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-interval.html>`__
    """

    props: PropsDictType = {
        "CalendarInterval": (CalendarInterval, False),
        "RollingInterval": (RollingInterval, False),
    }


class Goal(AWSProperty):
    """
    `Goal <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-goal.html>`__
    """

    props: PropsDictType = {
        "AttainmentGoal": (double, False),
        "Interval": (Interval, False),
        "WarningThreshold": (double, False),
    }


class Dimension(AWSProperty):
    """
    `Dimension <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-dimension.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
        "Value": (str, True),
    }


class Metric(AWSProperty):
    """
    `Metric <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-metric.html>`__
    """

    props: PropsDictType = {
        "Dimensions": ([Dimension], False),
        "MetricName": (str, False),
        "Namespace": (str, False),
    }


class MetricStat(AWSProperty):
    """
    `MetricStat <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-metricstat.html>`__
    """

    props: PropsDictType = {
        "Metric": (Metric, True),
        "Period": (integer, True),
        "Stat": (str, True),
        "Unit": (str, False),
    }


class MetricDataQuery(AWSProperty):
    """
    `MetricDataQuery <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-metricdataquery.html>`__
    """

    props: PropsDictType = {
        "AccountId": (str, False),
        "Expression": (str, False),
        "Id": (str, True),
        "MetricStat": (MetricStat, False),
        "ReturnData": (boolean, False),
    }


class MonitoredRequestCountMetric(AWSProperty):
    """
    `MonitoredRequestCountMetric <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-monitoredrequestcountmetric.html>`__
    """

    props: PropsDictType = {
        "BadCountMetric": ([MetricDataQuery], False),
        "GoodCountMetric": ([MetricDataQuery], False),
    }


class RequestBasedSliMetric(AWSProperty):
    """
    `RequestBasedSliMetric <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-requestbasedslimetric.html>`__
    """

    props: PropsDictType = {
        "KeyAttributes": (dict, False),
        "MetricType": (str, False),
        "MonitoredRequestCountMetric": (MonitoredRequestCountMetric, False),
        "OperationName": (str, False),
        "TotalRequestCountMetric": ([MetricDataQuery], False),
    }


class RequestBasedSli(AWSProperty):
    """
    `RequestBasedSli <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-requestbasedsli.html>`__
    """

    props: PropsDictType = {
        "ComparisonOperator": (str, False),
        "MetricThreshold": (double, False),
        "RequestBasedSliMetric": (RequestBasedSliMetric, True),
    }


class SliMetric(AWSProperty):
    """
    `SliMetric <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-slimetric.html>`__
    """

    props: PropsDictType = {
        "KeyAttributes": (dict, False),
        "MetricDataQueries": ([MetricDataQuery], False),
        "MetricType": (str, False),
        "OperationName": (str, False),
        "PeriodSeconds": (integer, False),
        "Statistic": (str, False),
    }


class Sli(AWSProperty):
    """
    `Sli <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationsignals-servicelevelobjective-sli.html>`__
    """

    props: PropsDictType = {
        "ComparisonOperator": (str, True),
        "MetricThreshold": (double, True),
        "SliMetric": (SliMetric, True),
    }


class ServiceLevelObjective(AWSObject):
    """
    `ServiceLevelObjective <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-applicationsignals-servicelevelobjective.html>`__
    """

    resource_type = "AWS::ApplicationSignals::ServiceLevelObjective"

    props: PropsDictType = {
        "Description": (str, False),
        "Goal": (Goal, False),
        "Name": (str, True),
        "RequestBasedSli": (RequestBasedSli, False),
        "Sli": (Sli, False),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags


class X12Details(AWSProperty):
    """
    `X12Details <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-b2bi-transformer-x12details.html>`__
    """

    props: PropsDictType = {
        "TransactionSet": (str, False),
        "Version": (str, False),
    }


class EdiType(AWSProperty):
    """
    `EdiType <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-b2bi-transformer-editype.html>`__
    """

    props: PropsDictType = {
        "X12Details": (X12Details, True),
    }


class S3Location(AWSProperty):
    """
    `S3Location <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-b2bi-capability-s3location.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, False),
        "Key": (str, False),
    }


class EdiConfiguration(AWSProperty):
    """
    `EdiConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-b2bi-capability-ediconfiguration.html>`__
    """

    props: PropsDictType = {
        "InputLocation": (S3Location, True),
        "OutputLocation": (S3Location, True),
        "TransformerId": (str, True),
        "Type": (EdiType, True),
    }


class CapabilityConfiguration(AWSProperty):
    """
    `CapabilityConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-b2bi-capability-capabilityconfiguration.html>`__
    """

    props: PropsDictType = {
        "Edi": (EdiConfiguration, True),
    }


class Capability(AWSObject):
    """
    `Capability <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-b2bi-capability.html>`__
    """

    resource_type = "AWS::B2BI::Capability"

    props: PropsDictType = {
        "Configuration": (CapabilityConfiguration, True),
        "InstructionsDocuments": ([S3Location], False),
        "Name": (str, True),
        "Tags": (Tags, False),
        "Type": (str, True),
    }


class Partnership(AWSObject):
    """
    `Partnership <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-b2bi-partnership.html>`__
    """

    resource_type = "AWS::B2BI::Partnership"

    props: PropsDictType = {
        "Capabilities": ([str], False),
        "Email": (str, True),
        "Name": (str, True),
        "Phone": (str, False),
        "ProfileId": (str, True),
        "Tags": (Tags, False),
    }


class Profile(AWSObject):
    """
    `Profile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-b2bi-profile.html>`__
    """

    resource_type = "AWS::B2BI::Profile"

    props: PropsDictType = {
        "BusinessName": (str, True),
        "Email": (str, False),
        "Logging": (str, True),
        "Name": (str, True),
        "Phone": (str, True),
        "Tags": (Tags, False),
    }


class Transformer(AWSObject):
    """
    `Transformer <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-b2bi-transformer.html>`__
    """

    resource_type = "AWS::B2BI::Transformer"

    props: PropsDictType = {
        "EdiType": (EdiType, True),
        "FileFormat": (str, True),
        "MappingTemplate": (str, True),
        "Name": (str, True),
        "SampleDocument": (str, False),
        "Status": (str, True),
        "Tags": (Tags, False),
    }
